@@ -60,7 +60,10 @@ using namespace KTextEditor;
 
 namespace KDevelop {
 
-struct CompletionWorkerThread : public QThread {
+class CompletionWorkerThread : public QThread
+{
+public:
+
    CompletionWorkerThread(CodeCompletionModel* model) : QThread(model), m_model(model), m_worker(0) {
    }
    ~CompletionWorkerThread() {
@@ -208,10 +211,8 @@ void CodeCompletionModel::completionInvokedInternal(KTextEditor::View* view, con
 
     lock.unlock();
 
-#if KDE_IS_VERSION(4,2,85)
     if(m_forceWaitForModel)
       emit waitForReset();
-#endif
     
     emit completionsNeeded(thisContext, range.start(), view);
   } else {
