@@ -358,6 +358,7 @@ ClassIdentifierPage::ClassIdentifierPage(QWizard* parent)
     connect(d->classid->removeInheritancePushButton, SIGNAL(pressed()), this, SLOT(removeInheritance()));
     connect(d->classid->moveUpPushButton, SIGNAL(pressed()), this, SLOT(moveUpInheritance()));
     connect(d->classid->moveDownPushButton, SIGNAL(pressed()), this, SLOT(moveDownInheritance()));
+    connect(d->classid->inheritanceList, SIGNAL(currentRowChanged(int)), this, SLOT(checkMoveButtonState()));
 
     registerField("classIdentifier*", d->classid->identifierLineEdit);
     registerField("classInheritance", this, "inheritance", SIGNAL(inheritanceChanged()));
@@ -399,6 +400,8 @@ void ClassIdentifierPage::removeInheritance()
     if (d->classid->inheritanceList->count() == 0)
         d->classid->removeInheritancePushButton->setEnabled(false);
 
+    checkMoveButtonState();
+
     emit inheritanceChanged();
 }
 
@@ -412,6 +415,7 @@ void ClassIdentifierPage::moveUpInheritance()
 
     QListWidgetItem* item = d->classid->inheritanceList->takeItem(currentRow);
     d->classid->inheritanceList->insertItem(currentRow - 1, item);
+    d->classid->inheritanceList->setCurrentItem(item);
 
     emit inheritanceChanged();
 }
@@ -426,6 +430,7 @@ void ClassIdentifierPage::moveDownInheritance()
 
     QListWidgetItem* item = d->classid->inheritanceList->takeItem(currentRow);
     d->classid->inheritanceList->insertItem(currentRow + 1, item);
+    d->classid->inheritanceList->setCurrentItem(item);
 
     emit inheritanceChanged();
 }
