@@ -17,6 +17,7 @@
 */
 
 #include "use.h"
+#include "topducontext.h"
 
 
 using namespace KTextEditor;
@@ -24,6 +25,10 @@ using namespace KTextEditor;
 namespace KDevelop
 {
 
+KDevelop::Declaration* Use::usedDeclaration(KDevelop::TopDUContext* topContext) {
+  return topContext->usedDeclarationForIndex(m_declarationIndex);
+}
+
 }
 
 // kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
