@@ -156,7 +156,7 @@ CodeHighlightingInstance* CodeHighlighting::createInstance() const
 
 void CodeHighlighting::highlightDUChain(TopDUContext* context) const
 {
-  kDebug() << "highlighting du chain" << context->url().c_str();
+  kDebug() << "highlighting du chain" << context->url().toUrl();
 
   DUChainReadLocker lock(DUChain::lock());
 
@@ -215,6 +215,7 @@ void CodeHighlightingInstance::highlightDUChainSimple(DUContext* context) const
     return;
   }
 
+  ///TODO: 4.1 make this overloadable, e.g. in PHP we also want local colorization in global context
   bool isInFunction = context->type() == DUContext::Function || (context->type() == DUContext::Other && context->owner());
 
   if( isInFunction && m_highlighting->m_localColorization ) {
@@ -470,25 +471,7 @@ void CodeHighlightingInstance::highlightUse(DUContext* context, int index, const
 void CodeHighlightingInstance::highlightUses(DUContext* context) const
 {
   for(int a = 0; a < context->usesCount(); ++a) {
-    if (SmartRange* range = context->useSmartRange(a)) {
-      Types type = ErrorVariableType;
-      Declaration* decl = context->topContext()->usedDeclarationForIndex(context->uses()[a].m_declarationIndex);
-      if (decl)
-        type = typeForDeclaration(decl, context);
-
-    LOCK_SMART(range);
-
-    if(!m_highlighting->isCodeHighlight(range->attribute()))
-      continue;
-
-    if(type != ErrorVariableType || ICore::self()->languageController()->completionSettings()->highlightSemanticProblems())
-        range->setAttribute(m_highlighting->attributeForType(type, ReferenceContext, QColor(QColor::Invalid)));
-    else
-        range->setAttribute(KTextEditor::Attribute::Ptr());
-
-//     kDebug() << range->attribute()->underlineStyle() << range->attribute()->background().iscolor().isValid();
-    Q_ASSERT(m_highlighting->isCodeHighlight(range->attribute()));
-    }
+    highlightUse(context, a, QColor(QColor::Invalid));
   }
 }
 
