@@ -168,12 +168,14 @@ K_EXPORT_PLUGIN(ContextBrowserFactory(KAboutData("kdevcontextbrowser","kdevconte
 
 ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
     : KDevelop::IPlugin(ContextBrowserFactory::componentData(), parent)
-    , m_backupsMutex(QMutex::Recursive), m_viewFactory(new ContextBrowserViewFactory(this))
+    , m_backupsMutex(QMutex::Recursive)
+    , m_viewFactory(new ContextBrowserViewFactory(this)), m_lastInsertionDocument(0)
 {
   core()->uiController()->addToolView(i18n("Code Browser"), m_viewFactory);
 
   connect( core()->documentController(), SIGNAL( textDocumentCreated( KDevelop::IDocument* ) ), this, SLOT( textDocumentCreated( KDevelop::IDocument* ) ) );
   connect( core()->documentController(), SIGNAL( documentClosed( KDevelop::IDocument* ) ), this, SLOT( documentClosed( KDevelop::IDocument* ) ) );
+  connect( core()->documentController(), SIGNAL( documentActivated( KDevelop::IDocument* ) ), this, SLOT( documentActivated( KDevelop::IDocument* ) ) );
   connect( core()->languageController()->backgroundParser(), SIGNAL(parseJobFinished(KDevelop::ParseJob*)), this, SLOT(parseJobFinished(KDevelop::ParseJob*)));
 
   connect( DUChain::self(), SIGNAL( declarationSelected(DeclarationPointer) ), this, SLOT( declarationSelectedInUI(DeclarationPointer) ) );
@@ -816,6 +818,14 @@ void ContextBrowserPlugin::documentClosed( KDevelop::IDocument* /*document*/ )
 {
 }
 
+void ContextBrowserPlugin::documentActivated( IDocument* doc )
+{
+  if (doc->textDocument() && doc->textDocument()->activeView())
+  {
+    cursorPositionChanged(doc->textDocument()->activeView(), doc->textDocument()->activeView()->cursorPosition());
+  }
+}
+
 void ContextBrowserPlugin::documentDestroyed( QObject* /*obj*/ )
 {
 }
@@ -938,7 +948,7 @@ void ContextBrowserPlugin::switchUse(bool forward)
         KDevVarLengthArray<IndexedTopDUContext> usingFiles = DUChain::uses()->uses(decl->id());
         
         if(DUChainUtils::contextHasUse(decl->topContext(), decl) && usingFiles.indexOf(decl->topContext()) == -1)
-          usingFiles.insert(decl->topContext(), 0);
+          usingFiles.insert(0, decl->topContext());
         
         if(decl->range().contains(c) && decl->url() == chosen->url()) {
             //The cursor is directly on the declaration. Jump to the first or last use.
