@@ -367,7 +367,7 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
             m_currentSession = 0;
             emit currentSessionChanged(0);
             Sublime::MainWindow* mainWindow = Core::self()->uiControllerInternal()->activeSublimeWindow();
-            if (mainWindow->area()->objectName() != "code") {
+            if (mainWindow && mainWindow->area()->objectName() != "code") {
                 QString workingSet = mainWindow->area()->workingSet();
                 ICore::self()->uiController()->switchToArea("code", IUiController::ThisWindow);
                 mainWindow->area()->setWorkingSet(workingSet);
@@ -380,6 +380,7 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
 
 void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, IDebugSession *session)
 {
+    Q_UNUSED(session);
     if((Core::self()->setupFlags() & Core::NoUi)) return;
 
     kDebug() << state;
@@ -411,7 +412,7 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
             //m_restartDebugger->setEnabled(false);
             break;
     }
-    if (state == IDebugSession::PausedState) {
+    if (state == IDebugSession::PausedState && ICore::self()->uiController()->activeMainWindow()) {
         ICore::self()->uiController()->activeMainWindow()->activateWindow();
     }
 }
