@@ -36,6 +36,7 @@
 class ProvidersModel : public QAbstractListModel
 {
     public:
+        
         ProvidersModel(QObject* parent = 0)
             : QAbstractListModel(parent)
             , mProviders(KDevelop::ICore::self()->documentationController()->documentationProviders())
@@ -61,6 +62,10 @@ class ProvidersModel : public QAbstractListModel
             return mProviders.count();
         }
         
+        QList<KDevelop::IDocumentationProvider*> providers() {
+            return mProviders;
+        }
+        
         KDevelop::IDocumentationProvider* provider(int pos) const
         {
             return mProviders[pos];
@@ -79,22 +84,33 @@ DocumentationView::DocumentationView(QWidget* parent)
 {
     setWindowIcon(KIcon("documentation"));
     setLayout(new QVBoxLayout(this));
+    layout()->setMargin(0);
+    layout()->setSpacing(0);
     mActions=new KToolBar(this);
+    mActions->setToolButtonStyle(Qt::ToolButtonIconOnly);
     layout()->addWidget(mActions);
     mBack=mActions->addAction(KIcon("go-previous"), i18n("Back"));
     mForward=mActions->addAction(KIcon("go-next"), i18n("Forward"));
     mActions->addSeparator();
+    mActions->addAction(KIcon("go-home"), i18n("Home"), this, SLOT(showHome()));
     mProviders=new QComboBox(mActions);
     mProviders->setFocusPolicy(Qt::NoFocus);
     mProvidersModel=new ProvidersModel(mProviders);
     mProviders->setModel(mProvidersModel);
+    foreach(KDevelop::IDocumentationProvider* p, mProvidersModel->providers()) {
+        connect(dynamic_cast<QObject*>(p), SIGNAL(addHistory(KSharedPtr<KDevelop::IDocumentation>)),
+                SLOT(addHistory(KSharedPtr<KDevelop::IDocumentation>)));
+    }
+    
     connect(mProviders, SIGNAL(activated(int)), SLOT(changedProvider(int)));
     mIdentifiers=new KLineEdit(mActions);
     mIdentifiers->setClearButtonShown(true);
     mIdentifiers->setCompleter(new QCompleter(mIdentifiers));
 //     mIdentifiers->completer()->setCompletionMode(QCompleter::UnfilteredPopupCompletion);
     mIdentifiers->completer()->setCaseSensitivity(Qt::CaseInsensitive);
-    mIdentifiers->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+
+    /* vertical size policy should be left to the style. */
+    mIdentifiers->setSizePolicy(QSizePolicy::Expanding, mIdentifiers->sizePolicy().verticalPolicy());
     connect(mIdentifiers, SIGNAL(returnPressed()), SLOT(changedSelection()));
     connect(mIdentifiers->completer(), SIGNAL(activated(QModelIndex)), SLOT(changeProvider(QModelIndex)));
     
@@ -107,10 +123,6 @@ DocumentationView::DocumentationView(QWidget* parent)
     connect(mForward, SIGNAL(triggered()), this, SLOT(browseForward()));
     mCurrent=mHistory.end();
     
-    QLabel* message=new QLabel(i18n("There is no documentation selected yet"), this);
-    message->setAlignment(Qt::AlignVCenter | Qt::AlignHCenter);
-    layout()->addWidget(message);
-    
     if(mProvidersModel->rowCount(QModelIndex())>0)
         changedProvider(0);
 }
@@ -133,6 +145,13 @@ void DocumentationView::browseForward()
     updateView();
 }
 
+void DocumentationView::showHome()
+{
+    KDevelop::IDocumentationProvider* prov=mProvidersModel->provider(mProviders->currentIndex());
+    
+    showDocumentation(prov->homePage());
+}
+
 void DocumentationView::changedSelection()
 {
     changeProvider(mIdentifiers->completer()->currentIndex());
@@ -142,7 +161,8 @@ void DocumentationView::changeProvider(const QModelIndex& idx)
 {
     if(idx.isValid())
     {
-        KSharedPtr<KDevelop::IDocumentation> doc=mProvidersModel->provider(mProviders->currentIndex())->documentationForIndex(idx);
+        KDevelop::IDocumentationProvider* prov=mProvidersModel->provider(mProviders->currentIndex());
+        KSharedPtr<KDevelop::IDocumentation> doc=prov->documentationForIndex(idx);
         if(doc)
             showDocumentation(doc);
     }
@@ -152,11 +172,16 @@ void DocumentationView::showDocumentation(KSharedPtr< KDevelop::IDocumentation >
 {
     kDebug(9529) << "showing" << doc->name();
     
+    addHistory(doc);
+    updateView();
+}
+
+void DocumentationView::addHistory(KSharedPtr< KDevelop::IDocumentation > doc)
+{
     mBack->setEnabled( !mHistory.isEmpty() );
     mForward->setEnabled(false);
     mHistory.append(doc);
     mCurrent=mHistory.end()-1;
-    updateView();
 }
 
 void DocumentationView::updateView()
@@ -166,20 +191,12 @@ void DocumentationView::updateView()
     mIdentifiers->setText((*mCurrent)->name());
     
     QLayoutItem* lastview=layout()->takeAt(1);
-    if(lastview->widget()->parent()==this)
+    if(lastview && lastview->widget()->parent()==this)
         lastview->widget()->deleteLater();
     
     delete lastview;
     
-    QWidget* w;
-    if((*mCurrent)->providesWidget())
-        w=(*mCurrent)->documentationWidget(this);
-    else {
-        QTextBrowser* widget=new QTextBrowser(this);
-        widget->setReadOnly(true);
-        widget->setText((*mCurrent)->description());
-        w=widget;
-    }
+    QWidget* w=(*mCurrent)->documentationWidget(this);
     Q_ASSERT(w);
     layout()->addWidget(w);
 }
@@ -188,4 +205,6 @@ void DocumentationView::changedProvider(int row)
 {
     mIdentifiers->completer()->setModel(mProvidersModel->provider(row)->indexModel());
     mIdentifiers->clear();
+    
+    showHome();
 }
