@@ -26,6 +26,7 @@ Boston, MA 02110-1301, USA.
 #include <QtGui/QDockWidget>
 #include <QtGui/QDragEnterEvent>
 #include <QtGui/QDropEvent>
+#include <QtGui/QMenuBar>
 #include <QtCore/QMimeData>
 
 #include <KDE/KApplication>
@@ -36,7 +37,9 @@ Boston, MA 02110-1301, USA.
 #include <ktemporaryfile.h>
 #include <kactioncollection.h>
 #include <kdebug.h>
+#include <ktexteditor/document.h>
 #include <ktexteditor/view.h>
+#include <kshortcutsdialog.h>
 #include <kxmlguifactory.h>
 #include <ktoggleaction.h>
 
@@ -66,14 +69,8 @@ namespace KDevelop
 
 void MainWindow::applyMainWindowSettings(const KConfigGroup& config, bool force)
 {
-    KXmlGuiWindow::applyMainWindowSettings(config, force);
-    
-    //When merging in a view, we re-structure the main-menu afterwards.
-    //When re-building the GUI from somewhere else (for example the toolbars were re-configured),
-    //we need to re-merge the menu, so that the menu can be re-structured again.
-    //We do this by simply calling changeActiveView(activeView()).
     if(!d->changingActiveView())
-        d->mergeView(activeView());
+        KXmlGuiWindow::applyMainWindowSettings(config, force);
 }
 
 QWidget* MainWindow::customButtonForAreaSwitcher ( Sublime::Area* area )
@@ -130,6 +127,42 @@ MainWindow::~ MainWindow()
     Core::self()->uiControllerInternal()->mainWindowDeleted(this);
 }
 
+QAction* MainWindow::createCustomElement(QWidget* parent, int index, const QDomElement& element)
+{
+    QAction* before = 0L;
+    if (index > 0 && index < parent->actions().count())
+        before = parent->actions().at(index);
+
+    //KDevelop needs to ensure that separators defined as <Separator style="visible" />
+    //are always shown in the menubar. For those, we create special disabled actions
+    //instead of calling QMenuBar::addSeparator() because menubar separators are ignored
+    if (element.tagName().toLower() == QLatin1String("separator")
+            && element.attribute("style") == QLatin1String("visible")) {
+        if ( QMenuBar* bar = qobject_cast<QMenuBar*>( parent ) ) {
+            QAction *separatorAction = new QAction("|", this);
+            bar->insertAction( before, separatorAction );
+            separatorAction->setDisabled(true);
+            return separatorAction;
+        }
+    }
+
+    return KXMLGUIBuilder::createCustomElement(parent, index, element);
+}
+
+QWidget* MainWindow::createContainer(QWidget* parent, int index,
+    const QDomElement& element, QAction*& containerAction)
+{
+#if KDE_VERSION < KDE_MAKE_VERSION(4, 4, 0)
+    //for KDE < 4.4 we need to remove "Editor" toplevel menu - it will
+    //always be empty because our custom katepartui.rc is not used
+    const QString tagName = element.tagName().toLower();
+    if (tagName == QLatin1String("menu") &&
+            element.attribute(QLatin1String("name")).toUtf8() == "editor")
+        return 0;
+#endif
+    return KXMLGUIBuilder::createContainer(parent, index, element, containerAction);
+}
+
 void MainWindow::dragEnterEvent( QDragEnterEvent* ev )
 {
     if( ev->mimeData()->hasFormat( "text/uri-list" ) && ev->mimeData()->hasUrls() )
@@ -144,7 +177,7 @@ void MainWindow::dropEvent( QDropEvent* ev )
     if(dropToView)
         activateView(dropToView);
     
-    foreach( QUrl u, ev->mimeData()->urls() )
+    foreach( const QUrl& u, ev->mimeData()->urls() )
     {
         Core::self()->documentController()->openDocument( KUrl( u ) );
     }
@@ -188,7 +221,21 @@ void MainWindow::configureShortcuts()
 {
     ///Workaround for a problem with the actions: Always start the shortcut-configuration in the first mainwindow, then propagate the updated
     ///settings into the other windows
-    Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->configureShortcuts();
+
+
+// We need to bring up the shortcut dialog ourself instead of 
+//      Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->configureShortcuts();
+// so we can connect to the saved() signal to propagate changes in the editor shortcuts
+
+   KShortcutsDialog dlg(KShortcutsEditor::AllActions, KShortcutsEditor::LetterShortcutsAllowed, this);
+    foreach (KXMLGUIClient *client, Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients())
+    {
+        if(client && !client->xmlFile().isEmpty())
+            dlg.addCollection( client->actionCollection() );
+    }
+    
+    connect(&dlg, SIGNAL(saved()), SLOT(shortcutsChanged()));
+    dlg.configure(true);
 
     QMap<QString, QKeySequence> shortcuts;
     foreach(KXMLGUIClient* client, Core::self()->uiControllerInternal()->mainWindows()[0]->guiFactory()->clients()) {
@@ -209,8 +256,29 @@ void MainWindow::configureShortcuts()
             }
         }
     }
+    
 }
 
+void MainWindow::shortcutsChanged()
+{
+    //propagate shortcut changes to all the opened text documents by reloading the UI XML file
+    KTextEditor::Document *activeDocument = Core::self()->documentController()->activeDocument()->textDocument();
+    if (activeDocument) {
+
+        KTextEditor::View *activeClient = activeDocument->activeView();
+        
+        foreach(IDocument * doc, Core::self()->documentController()->openDocuments()) {
+            KTextEditor::Document *textDocument = doc->textDocument();
+            foreach(KTextEditor::View *client, textDocument->views()) {
+                 if (client != activeClient) {
+                    client->reloadXML();
+                }
+            }
+        }
+    }
+}
+
+
 void MainWindow::initialize()
 {
     KStandardAction::keyBindings(this, SLOT(configureShortcuts()), actionCollection());
@@ -324,6 +392,7 @@ void MainWindow::tabContextMenuRequested(Sublime::View* view, KMenu* menu)
 
 void MainWindow::tabToolTipRequested(Sublime::View* view, QPoint point)
 {
+    Q_UNUSED(point);
     static QPointer<NavigationToolTip> toolTip;
     
     if(toolTip)
