@@ -29,6 +29,7 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
+#include <kstandarddirs.h>
 #include <kxmlguifactory.h>
 #include <kactioncollection.h>
 #include <kstatusbar.h>
@@ -293,6 +294,15 @@ QWidget *TextDocument::createViewWidget(QWidget *parent)
         view->setContextMenu( view->defaultContextMenu() );
         #endif
         connect(view, SIGNAL(contextMenuAboutToShow(KTextEditor::View*,QMenu*)), this, SLOT(populateContextMenu(KTextEditor::View*,QMenu*)));
+
+        #if KDE_VERSION >= KDE_MAKE_VERSION(4, 4, 0)
+        //in KDE >= 4.4 we can use KXMLGuiClient::replaceXMLFile to provide
+        //katepart with out own restructured UI configuration
+        QStringList katePartUIs = KGlobal::mainComponent().dirs()->findAllResources("data", "kdevelop/katepartui.rc");
+        const QString katePartUI = katePartUIs.last();
+        const QString katePartLocalUI = KStandardDirs::locateLocal("data", "kdevelop/katepartui.rc");
+        view->replaceXMLFile(katePartUI, katePartLocalUI);
+        #endif
     }
 
     if (KTextEditor::CodeCompletionInterface* cc = dynamic_cast<KTextEditor::CodeCompletionInterface*>(view))
