@@ -26,11 +26,14 @@
 #include <KIcon>
 #include <kdebug.h>
 #include <klocale.h>
+#include <kglobal.h>
+#include <kshortcutwidget.h>
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KAcceleratorManager>
 #include <KMenu>
 #include <KToolBar>
+#include <KDialog>
 
 #include "area.h"
 #include "view.h"
@@ -105,38 +108,42 @@ void IdealToolButton::paintEvent(QPaintEvent *event)
     if (_area == Qt::TopDockWidgetArea || _area == Qt::BottomDockWidgetArea) {
         QToolButton::paintEvent(event);
     } else {
-        QStyleOptionToolButton opt;
-        initStyleOption(&opt);
-        // If we're drawing icons only it looks better if they're not rotated
-        QPixmap ic = icon().pixmap(QSize(16,16), QIcon::Normal, QIcon::On);
-        
+        // rotated paint
+        QStylePainter painter(this);
+        QStyleOptionToolButton option;
+        initStyleOption(&option);
+
+        // first draw normal frame and not text/icon
+        option.text = QString();
+        option.icon = QIcon();
+        painter.drawComplexControl(QStyle::CC_ToolButton, option);
+
+        // rotate the options
+        QSize size( option.rect.size() );
+        size.transpose();
+        option.rect.setSize( size );
+
+        // rotate the painter
+        if(_area == Qt::LeftDockWidgetArea) {
+            painter.translate( 0, height() );
+            painter.rotate( -90 );
+        } else {
+            painter.translate( width(), 0 );
+            painter.rotate( 90 );
+        }
+
+        // paint text and icon
+        option.text = text();
+        QPixmap ic = icon().pixmap(option.iconSize, QIcon::Normal, QIcon::On);
         QTransform tf;
         if(_area == Qt::LeftDockWidgetArea) {
             tf = tf.rotate(90);
         } else {
             tf = tf.rotate(-90);
         }
-        opt.icon = ic.transformed( tf, Qt::SmoothTransformation );
-        
-        opt.rect.setSize(QSize(opt.rect.height(), opt.rect.width()));
-
-        QPixmap pix(opt.rect.width(), opt.rect.height());
-        QStylePainter painter(&pix, this);
-        painter.fillRect(pix.rect(), opt.palette.background());
-        painter.drawComplexControl(QStyle::CC_ToolButton, opt);
+        option.icon = ic.transformed( tf, Qt::SmoothTransformation );
+        painter.drawControl(QStyle::CE_ToolButtonLabel, option);
         painter.end();
-
-        QPainter p(this);
-
-        if (_area == Qt::LeftDockWidgetArea) {
-            p.translate(0, height());
-            p.rotate(-90);
-        } else {
-            p.translate(width(), 0);
-            p.rotate(90);
-        }
-
-        p.drawPixmap(0, 0, pix);
     }
 }
 
@@ -326,12 +333,13 @@ void IdealButtonBarWidget::actionToggled(bool state)
     button->blockSignals(blocked);
 }
 
-IdealDockWidget::IdealDockWidget(QWidget *parent)
+IdealDockWidget::IdealDockWidget(IdealMainWidget *parent)
     : QDockWidget(parent),
       m_area(0),
       m_view(0),
       m_docking_area(Qt::NoDockWidgetArea),
-      m_maximized(false)
+      m_maximized(false),
+      m_mainWidget(parent)
 {
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, SIGNAL(customContextMenuRequested(QPoint)),
@@ -474,6 +482,9 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
         right->setChecked(true);
     /// end position menu
 
+    menu.addSeparator();
+    QAction *setShortcut = menu.addAction(KIcon("configure-shortcuts"), i18n("Assign Shortcut..."));
+
     menu.addSeparator();
     QAction* remove = menu.addAction(KIcon("dialog-close"), i18n("Remove"));
     QAction* toggleAnchored;
@@ -487,7 +498,7 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
         menu.addSeparator();
         QToolBar* bar = 0;
         foreach( QObject* child, toolView->children() ) {
-            if ( bar = qobject_cast<QToolBar*>(child) ) {
+            if ( (bar = qobject_cast<QToolBar*>(child)) ) {
                 break;
             }
         }
@@ -507,6 +518,31 @@ void IdealDockWidget::contextMenuRequested(const QPoint &point)
         } else if ( triggered == toggleAnchored ) {
             setAnchored(!isAnchored(), true);
             return;
+        } else if ( triggered == setShortcut ) {
+            KDialog *dialog = new KDialog(this);
+            dialog->setCaption(i18n("Assign Shortcut For '%1' Tool View", m_view->document()->title()));
+            dialog->setButtons( KDialog::Ok | KDialog::Cancel );
+            KShortcutWidget *w = new KShortcutWidget(dialog);
+            KShortcut shortcut;
+            shortcut.setPrimary(m_mainWidget->actionForView(m_view)->shortcuts().value(0));
+            shortcut.setAlternate(m_mainWidget->actionForView(m_view)->shortcuts().value(1));
+            w->setShortcut(shortcut);
+            dialog->setMainWidget(w);
+
+            if (dialog->exec() == QDialog::Accepted) {
+                m_mainWidget->actionForView(m_view)->setShortcuts(w->shortcut().toList());
+
+                //save shortcut config
+                KConfigGroup config = KGlobal::config()->group("UI");
+                QStringList shortcuts;
+                shortcuts << w->shortcut().primary().toString();
+                shortcuts << w->shortcut().alternate().toString();
+                config.writeEntry(QString("Shortcut for %1").arg(m_view->document()->title()), shortcuts);
+                config.sync();
+            }
+
+            delete dialog;
+            return;
         }
 
         Sublime::Position pos;
@@ -614,7 +650,6 @@ void IdealMainWidget::addView(Qt::DockWidgetArea area, View* view)
 
     dock->setWindowTitle(view->widget()->windowTitle());
     dock->setWindowIcon(view->widget()->windowIcon());
-    dock->setAutoFillBackground(true);
     dock->setFocusProxy(dock->widget());
 
     if (IdealButtonBarWidget* bar = barForRole(roleForArea(area))) {
@@ -622,6 +657,15 @@ void IdealMainWidget::addView(Qt::DockWidgetArea area, View* view)
             view->document()->title(), dock,
             static_cast<MainWindow*>(parent())->area(), view);
         m_dockwidget_to_action[dock] = m_view_to_action[view] = action;
+
+        //restore toolview shortcut config
+        KConfigGroup config = KGlobal::config()->group("UI");
+        QStringList shortcuts = config.readEntry(QString("Shortcut for %1").arg(view->document()->title()), QStringList());
+        KShortcut shortcut;
+        shortcut.setPrimary(shortcuts.value(0));
+        shortcut.setAlternate(shortcuts.value(1));
+        action->setShortcut(shortcut);
+
         m_docks->addAction(action);
         bar->show();
     }
@@ -877,7 +921,6 @@ IdealSplitterHandle::IdealSplitterHandle(Qt::Orientation orientation, QWidget* p
 {
     setCursor(orientation == Qt::Horizontal ? Qt::SplitVCursor : Qt::SplitHCursor);
     setMouseTracking(true);
-    setAutoFillBackground(true);
 }
 
 void IdealSplitterHandle::paintEvent(QPaintEvent *)
@@ -979,9 +1022,12 @@ void IdealMainWidget::showDock(IdealMainLayout::Role role, bool show)
     }
 
     if (show) {
-        if (IdealDockWidget* widget = m_mainLayout->lastDockWidget(role))
+        if (IdealDockWidget* widget = m_mainLayout->lastDockWidget(role)) {
             if (QAction *action = m_dockwidget_to_action.value(widget))
-                return action->setChecked(show);
+                action->setChecked(show);
+
+            widget->setFocus(Qt::ShortcutFocusReason);
+        }
 
         if (barForRole(role)->actions().count())
             barForRole(role)->actions().first()->setChecked(show);
